@@ -54,19 +54,31 @@ class DiscordpyPDAImplementation(engi.ConversationListImplementation):
 
         # noinspection PyMethodParameters
         class CustomClient(d.Client):
+            async def on_ready(cli):
+                log.debug("CustomClient is ready!")
+
+            async def on_error(self, event_method, *args, **kwargs):
+                log.error(f"An error occoured in CustomClient: {event_method!r} {args!r} {kwargs!r}")
+
             async def on_message(cli, message: d.Message):
+                log.debug("Triggered on_message, putting in dispenser...")
+
                 await self.put(
                     key=self._determine_key(message=message),
                     projectile=DiscordMessageReceived(event=message)
                 )
 
             async def on_message_edit(cli, message: d.Message):
+                log.debug("Triggered on_message_edit, putting in dispenser...")
+
                 await self.put(
                     key=self._determine_key(message=message),
                     projectile=DiscordMessageEdited(event=message)
                 )
 
             async def on_message_delete(cli, message: d.Message):
+                log.debug("Triggered on_message_delete, putting in dispenser...")
+
                 await self.put(
                     key=self._determine_key(message=message),
                     projectile=DiscordMessageDeleted(event=message)
